#
# spec file for package libexif-gtk
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libexif-gtk
BuildRequires:  automake
BuildRequires:  gettext
BuildRequires:  gtk2-devel
BuildRequires:  gtk3-devel
BuildRequires:  libexif-devel
BuildRequires:  libtool
URL:            http://libexif.sourceforge.net/
Summary:        GTK Widgets for Viewing EXIF Information
License:        GPL-2.0-or-later
Group:          System/Libraries
Version:        0.5.0
Release:        1.21
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        https://github.com/libexif/%{name}/archive/v%{version}.tar.gz
Requires:       libexif-gtk5 = %{version}

%description
This library contains GTK widgets for viewing EXIF information within
JPEG images created by some digital cameras.

%package -n libexif-gtk5
Summary:        GTK Widgets for Viewing EXIF Information
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n libexif-gtk5
This library contains GTK widgets for viewing EXIF information within
JPEG images created by some digital cameras.

%package devel
Summary:        GTK Widgets for Viewing EXIF Information
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       gtk2-devel
Requires:       libexif-devel

%description devel
This library contains GTK widgets for viewing EXIF information within
JPEG images created by some digital cameras.

%prep
%setup -q

%build
bash ./autogen.sh
%configure --with-pic \
	--disable-static
make %{?jobs:-j%jobs}

%install
%makeinstall
%find_lang %{name}-5
%{__rm} -f %{buildroot}%{_libdir}/*.la

%post -p /sbin/ldconfig -n libexif-gtk5

%postun -p /sbin/ldconfig -n libexif-gtk5

%files
%defattr(-,root,root)
%license COPYING
%doc ChangeLog

%files -n libexif-gtk5 -f %{name}-5.lang
%license COPYING
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%license COPYING
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/libexif-gtk

%changelog
* Mon Aug 31 2020 Marcus Meissner <meissner@suse.com>
- updated to 0.5.0 final
  * Enable AM_SILENT_RULES by default
  * Fix cross-compilation with pkg-config
  * Fix a bunch of compiler warnings
  * Remove unused macro files
  * Add continuous integration builds
* Fri May 30 2014 opensuse@dstoecker.de
- fix description to be UTF-8
* Sat Mar  9 2013 meissner@suse.com
- updated to 0.4.0 final
  * New translations: de, pl
  * Updated translations: es, fr, ru
  * Bug fixes: #1643242: added libexif-gtk-uninstalled.pc file
  * Proper setting of gettext parameters
  * libexif-gtk made compatible for both gtk2 (min version: 2.4) and gtk3
  * added --with-gtk3 option in configure.ac (default is gtk2)
  * encoding of source files set to utf-8
  * encoding of ru translation file set to utf-8
  * fixed internationalisation bugs in gtk-options.c & configure.ac
  * fixed bugs linked to gtk_notebook_remove_page action
  * Bug fixes: #2014281: fix display of GPSLatitude and GPSLatitudeRef names
  * fixed crash when viewing an enumerated tag with an unsupported value
  * fixed problem with handling the Flash tag in big-endian images
  * fixed thumbnail save function to actually save
* Fri Apr 16 2010 meissner@suse.de
- updated to 0.3.6cvs2
  - minor fixes
  - translation updates
  - adjusted to new libexif ABIs
- libexif-gtk4 is now libexif-gtk5
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Jan 26 2009 crrodriguez@suse.de
- remove "la" files
* Wed Jul  9 2008 sbrabec@suse.cz
- Added patch to get rid references to deprecated
  exif_tag_get_name() (fixes GPS Latitude).
- Split package according to shared library packaging policy.
* Tue Feb 27 2007 dmueller@suse.de
- adjust BuildRequires: libexif -> libexif-devel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jul 30 2004 meissner@suse.de
- Included patch so it works with libexif 0.6.*
* Fri Apr 23 2004 meissner@suse.de
- undeprecate, so it compiles.
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Tue May 13 2003 meissner@suse.de
- Updated to current CVS.
- Package translations too.
* Thu Jan 16 2003 ro@suse.de
- use gtk2-devel-packages in neededforbuild
* Wed Jan  8 2003 meissner@suse.de
- Updated to 0.3.3 (bugfixes mostly).
* Mon Nov 18 2002 meissner@suse.de
- Upgraded to 0.3.2 in preparation of gphoto2-2.1.1.
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
- changed neededforbuild <xdevel> to <>
* Wed Jul 24 2002 meissner@suse.de
- Upgraded to 0.3.1, disabled static libraries.
* Thu Feb  7 2002 meissner@suse.de
- Added xshared to needed_for_build.
* Tue Feb  5 2002 meissner@suse.de
- GTK widgets for browsing EXIF information. Used by gphoto/gtkam.
